@@ -5,12 +5,8 @@ from .testHelpers import get_cpp_fileinfo, get_cpp_function_list
 
 class Test_C_Token_extension(unittest.TestCase):
 
-    def test_marco_should_be_splitted_into_two_tokens(self):
-        extended = CLikeReader().preprocess(("# marco param1 param2", ), None)
-        self.assertEqual(["#marco", "param1 param2"], list(extended))
-
     def test_connecting_marcro(self):
-        extended = CLikeReader().preprocess(("a##b c", ), None)
+        extended = CLikeReader(None).preprocess(("a##b c", ))
         #tbd
 
 class Test_c_cpp_lizard(unittest.TestCase):
@@ -42,7 +38,43 @@ class Test_c_cpp_lizard(unittest.TestCase):
         self.assertEqual(1, len(result))
         self.assertEqual("fun", result[0].name)
         self.assertEqual("fun( xx oo )", result[0].long_name)
-    
+
+    def test_old_style_c_function(self):
+        result = get_cpp_function_list("""int fun(param) int praram; {}""")
+        self.assertEqual(1, len(result))
+
+    def test_complicated_c_function(self):
+        result = get_cpp_function_list("""int f(int(*)()){}""")
+        self.assertEqual('f', result[0].name)
+
+    def test_function_dec_with_throw(self):
+        result = get_cpp_function_list("""int fun() throw();void foo(){}""")
+        self.assertEqual(1, len(result))
+
+    def test_function_dec_followed_with_one_word_is_ok(self):
+        result = get_cpp_function_list("""int fun() no_throw {}""")
+        self.assertEqual(1, len(result))
+
+    def test_function_declaration_is_not_counted(self):
+        result = get_cpp_function_list("""int fun();class A{};""")
+        self.assertEqual(0, len(result))
+
+    def test_old_style_c_function_has_semicolon(self):
+        result = get_cpp_function_list("""{(void*)a}{}""")
+        self.assertEqual(0, len(result))
+
+    def test_typedef_is_not_old_style_c_function(self):
+        result = get_cpp_function_list('''typedef T() nT; foo(){}''')
+        self.assertEqual("foo", result[0].name)
+
+    def test_stupid_macro_before_function(self):
+        result = get_cpp_function_list('''T() foo(){}''')
+        self.assertEqual("foo", result[0].name)
+
+    def test_only_word_can_be_function_name(self):
+        result = get_cpp_function_list("""[(){}""")
+        self.assertEqual(0, len(result))
+
     def test_double_slash_within_string(self):
         result = get_cpp_function_list("""int fun(){char *a="\\\\";}""")
         self.assertEqual(1, len(result))
@@ -80,28 +112,43 @@ class Test_c_cpp_lizard(unittest.TestCase):
         self.assertEqual(2, len(result))
         self.assertEqual("c", result[0].name)
         self.assertEqual("d", result[1].name)
-        
+
     def test_template_as_reference(self):
         result = get_cpp_function_list("abc::def(a<b>& c){}")
         self.assertEqual(1, len(result))
 
+    def test_less_then_is_not_template(self):
+        result = get_cpp_function_list("def(<); foo(){}")
+        self.assertEqual(1, len(result))
+
     def test_template_with_pointer(self):
         result = get_cpp_function_list("abc::def (a<b*> c){}")
         self.assertEqual(1, len(result))
-        
+
+    def test_nested_template(self):
+        result = get_cpp_function_list("abc::def (a<b<c>> c){}")
+        self.assertEqual(1, len(result))
+
     def test_template_with_reference(self):
         result = get_cpp_function_list("void fun(t<int &>b){} ")
         self.assertEqual(1, len(result))
-        
+
     def test_template_with_reference_as_reference(self):
         result = get_cpp_function_list("void fun(t<const int&>&b){} ")
         self.assertEqual(1, len(result))
-       
+
+    def test_template_as_part_of_function_name(self):
+        result = get_cpp_function_list("void fun<a,b<c>>(){} ")
+        self.assertEqual('fun<a,b<c>>', result[0].name)
+
     def test_operator_overloading(self):
         result = get_cpp_function_list("bool operator +=(int b){}")
-        self.assertEqual(1, len(result))
         self.assertEqual("operator +=", result[0].name)
-                
+
+    def test_operator_with_complicated_name(self):
+        result = get_cpp_function_list("operator MyStruct&(){}")
+        self.assertEqual("operator MyStruct &", result[0].name)
+
     def test_operator_overloading_with_namespace(self):
         result = get_cpp_function_list("bool TC::operator !(int b){}")
         self.assertEqual(1, len(result))
@@ -116,7 +163,7 @@ class Test_c_cpp_lizard(unittest.TestCase):
         result = get_cpp_function_list('''A::A():a(1){}''')
         self.assertEqual(1, len(result))
         self.assertEqual("A::A", result[0].name)
-        
+
     def test_brakets_before_function(self):
         result = get_cpp_function_list('''()''')
         self.assertEqual(0, len(result))
@@ -124,17 +171,6 @@ class Test_c_cpp_lizard(unittest.TestCase):
 
 class Test_Preprocessing(unittest.TestCase):
 
-    def test_braces_in_harsh_else(self):
-        result = get_cpp_function_list('''int main(){
-                                        #ifndef NORBUS
-                                        {
-                                        #else
-                                        {
-                                        #endif
-                                        }
-                                    } void fun(){}''')
-        self.assertEqual(2, len(result))
-
     def test_content_macro_should_be_ignored(self):
         result = get_cpp_function_list(r'''
                     #define MTP_CHEC                    \
